@@ -17,11 +17,17 @@ class RemoteObject:
 		self.___client___ = client
 
 
-	def __getattribute__(self, name: str):
-		if name.startswith('___') and name.endswith('___') or name in {'__call__', '__init__'}:
+	def __getattribute__(self, name: str, force_remote=False):
+		def get_from_server():
+			return self.___client___.___call_server___('get', 'getattr', id=self.___id___, attribute=name)
+		if force_remote:
+			return get_from_server()
+		elif name.startswith('___') and name.endswith('___') or \
+		   name in {'__getattribute__', '__call__', '__init__', '__iter__', '__class__'}:
 			return object.__getattribute__(self, name)
 		else:
-			return self.___client___.___call_server___('get', 'getattr', id=self.___id___, attribute=name)
+			return get_from_server()
+
 
 
 	# TODO also set attribute
@@ -34,6 +40,22 @@ class RemoteObject:
 		                                           data=models.CallParameters(args=args, kwargs=kwargs).dict())
 
 
+	def __iter__(self):
+		list = self.___client___.___call_server___('get', 'iterate', id=self.___id___)
+		return list.__iter__()
+
+	def __getitem__(self, item):
+		return self.__getitem__(item)
+
+	@property
+	def __class__(self):
+		remote_class = self.__getattribute__('__class__', force_remote=True)
+		try:
+			return eval(remote_class.__name__)
+		except:
+			return remote_class
+
+
 
 
 
@@ -59,14 +81,22 @@ class Client(RemoteObject):
 		method = getattr(self.___session___, method)
 		url = f'{self.___server_address___}/{function}'
 		response = method(url, json=data, params=params)
+		json = response.json()
 
 		match response.status_code:
 			case 200:
-				object = models.ObjectInfo.construct(None, **response.json())
-				if object.basic:
-					return object.value
+				def parse(json):
+					object = models.ObjectInfo.construct(None, **json)
+					if object.basic:
+						return object.value
+					else:
+						return RemoteObject(object.id, self)
+
+				if isinstance(json, list):
+					return [parse(i) for i in json]
 				else:
-					return RemoteObject(object.id, self)
+					return parse(json)
+
 			case 404:
 				raise ObjectNotFoundError(response)
 			case _:
