@@ -42,6 +42,14 @@ class Server:
 				raise fastapi.HTTPException(404, str(e))
 			return _object_info(object)
 
+		@self.fastapi.get('/iterate')
+		def iterate_object(id: int):
+			try:
+				object = requested_objects[id]
+			except KeyError as e:
+				raise fastapi.HTTPException(404, str(e))
+			return [_object_info(i) for i in object]
+
 		@self.fastapi.post('/call')
 		def call_object(id: int, params: models.CallParameters):
 			try:
@@ -51,11 +59,15 @@ class Server:
 			result = params.use_on(object)
 			return _object_info(result)
 
-	def start(self):
-		uvicorn.run(self.fastapi, host='0.0.0.0', port=self.port)
+	def start(self, log=False):
+		if log:
+			log_level = None
+		else:
+			log_level = 'critical'
+		uvicorn.run(self.fastapi, host='0.0.0.0', port=self.port, log_level=log_level)
 
-	def start_in_thread(self):
-		threading.Thread(target=self.start, daemon=True).start()
+	def start_in_thread(self, log=False):
+		threading.Thread(target=self.start, kwargs={'log': log}, daemon=True).start()
 
 
 
